require 'liquid'

class Hash
  
  def respond_to?(name, include_private = false)
    return true if key?(name.to_s) || key?(name.to_sym)
    super
  end
  
  def method_missing(name, *args)
    return self[name.to_s] if key?(name.to_s)
    return self[name.to_sym] if key?(name.to_sym)
    super
  end

end

class Array



end

class String
  
  def withoutExtension
    parts = split(".")
    (parts.length > 1 ? parts[0..-2] : parts).join("")
  end
  
  def lowercased
    downcase
  end
  
  def uppercased
      upcase
  end
  
  def capitalized
    capitalize
  end
  
  def extension
    parts = split(".")
    parts.length > 1 ? parts[parts.length - 1] : ""
  end

  alias_method :without_extension, :withoutExtension

  liquid_methods :withoutExtension, :lowercased, :uppercased, :capitalized, :extension, :without_extension, :to_s
  
end

class File
  
  attr_reader :path
  
  def initialize(path)
    @path = path
  end
  
  def name
    parts = @path.split("/")
    parts.length > 1 ? parts[parts.length - 1] : @path
  end
  
  def to_s
    name
  end

  liquid_methods :path, :name, :to_s

end

class Point
  
  attr_reader :x, :y
  
  def initialize(x, y)
    @x = x
    @y = y
  end
  
  def to_s
      "{#{@x},#{@y}}"
  end

  liquid_methods :x, :y, :to_s
  
end

class Size
  
  attr_reader :width, :height
  
  def initialize(width, height)
    @width = width
    @height = height
  end
  
  def to_s
    "{#{@width},#{@height}}"
  end

  liquid_methods :width, :height, :to_s

end

class Rect
  
  attr_reader :origin, :size
  
  def initialize(origin, size)
    @origin = origin
    @size = size
  end
  
  def x; origin.x; end
  def y; origin.y; end
  def width; size.width; end
  def height; size.height; end
  def minX; origin.x; end
  def minY; origin.y; end
  def maxX; origin.x + size.width; end
  def maxY; origin.y + size.height; end
  
  def to_s
    "{#{origin},#{size}}"
  end

  alias_method :min_x, :minX
  alias_method :max_x, :maxX
  alias_method :min_y, :minY
  alias_method :max_y, :maxY

  liquid_methods :origin, :size, :minX, :minY, :maxX, :maxY, :min_x, :min_y, :max_x, :max_y, :x, :y, :width, :height, :to_s
  
end

class Sprite
  
  attr_reader :name, :pathName, :sourceColorRect, :sourceSize, :offset, :textureRect, :trimmed, :aliases
  
  def initialize(name, pathName, sourceColorRect, sourceSize, offset, textureRect, trimmed, aliases)
    @name = name
    @pathName = pathName
    @sourceColorRect = sourceColorRect
    @sourceSize = sourceSize
    @offset = offset
    @textureRect = textureRect
    @trimmed = trimmed
    @aliases = aliases
  end

  alias_method :path_name, :pathName
  alias_method :source_color_rect, :sourceColorRect
  alias_method :source_size, :sourceSize
  alias_method :texture_rect, :textureRect

  liquid_methods :name, :pathName, :sourceColorRect, :sourceSize, :offset, :textureRect, :trimmed, :aliases, :path_name, :source_color_rect, :source_size, :texture_rect
  
end

class Sheet
  
  attr_reader :coordinatesFile, :textureFile, :size
  
  def initialize(coordinatesFile, textureFile, size)
    @coordinatesFile = coordinatesFile
    @textureFile = textureFile
    @size = size
  end
  
  alias_method :coordinates_file, :coordinatesFile
  alias_method :texture_file, :textureFile

  liquid_methods :coordinatesFile, :textureFile, :size, :coordinates_file, :texture_file

end

class Target
  
  attr_reader :name, :scale, :scalePercentage, :scaleMode
  
  def initialize(name, scale, scalePercentage, scaleMode)
    @name = name
    @scale = scale
    @scalePercentage = scalePercentage
    @scaleMode = scaleMode
  end

  alias_method :scale_percentage, :scalePercentage
  alias_method :scale_mode, :scaleMode

  liquid_methods :name, :scale, :scalePercentage, :scaleMode, :scale_percentage, :scale_mode
  
end

class Metadata
  
  attr_reader :name, :version

  def initialize(name, version)
    @name = name
    @version = version
  end

  liquid_methods :name, :version
  
end
module Zwoptex

  def self.render_liquid_template(string, context)
    template = Liquid::Template.parse(string)
    template.render(context)
  end

  def self.render_ruby_template(string, context)
    context.instance_eval(string)
  end

end